@@ -1,4 +1,3 @@
-import json
 from enum import Enum
 from typing import Any
 from typing import Dict
@@ -15,7 +14,6 @@ from frinx.common.worker.worker import WorkerImpl
 from pydantic import BaseModel
 from pydantic import Extra
 from pydantic import Field
-from pydantic import PrivateAttr
 from pydantic import StrictBool
 from pydantic import root_validator
 from pydantic import validator
@@ -95,6 +93,11 @@ class WorkflowTaskImpl(BaseModel):
         validate_assignment = True
         validate_all = True
 
+    def output_ref(self, path: str | None = None) -> str:
+        if path == "" or path is None:
+            return f"${{{self.task_reference_name}.output}}"
+        return f"${{{self.task_reference_name}.output.{path}}}"
+
 
 class DoWhileTask(WorkflowTaskImpl):
     type = TaskType.DO_WHILE
@@ -433,12 +436,12 @@ class SubWorkflowTask(WorkflowTaskImpl):
         match sub_wf_def:
             case SubWorkflowFromDefParam():
                 workflow_inputs = sub_wf_def.name.WorkflowInput().__fields__.items()
-                for k, v in workflow_inputs:
-                    if k not in worker_inputs:
-                        if v.required is False:
+                for key, value in workflow_inputs:
+                    if key not in worker_inputs:
+                        if value.required is False:
                             pass
                         else:
-                            raise ValueError(f"Missing input {k}")
+                            raise ValueError(f"Missing input {key}")
                 values["sub_workflow_param"] = SubWorkflowParam(
                     name=sub_wf_def.name.__name__,
                     version=sub_wf_def.name.__fields__["version"].default,
@@ -479,12 +482,12 @@ class SimpleTask(WorkflowTaskImpl):
                     raise ValueError("Bad input for name")
                 values["name"] = task_def.WorkerDefinition.__fields__["name"].default  # type: ignore[attr-defined]
                 task_input = task_def.WorkerInput.__fields__.items()  # type: ignore[attr-defined]
-                for k, v in task_input:
-                    if k not in worker_inputs:
-                        if v.required is False:
+                for key, value in task_input:
+                    if key not in worker_inputs:
+                        if value.required is False:
                             pass
                         else:
-                            raise ValueError(f"Missing input {k}")
+                            raise ValueError(f"Missing input {key}")
         return values
 
 
